@@ -15,9 +15,10 @@ def _generate_transfer_mapping(
         and len(source) == len(destination)
     ):
         djsciops_utils.log(f"Upload mapping provided.")
+        # expect file_paths to be list of Path, object_paths to be list of PurePosixPath
         file_paths, object_paths = (source, destination)
         existing_objects = {
-            pathlib.Path(op.key).as_posix()
+            pathlib.PurePosixPath(op.key)
             for op in session.s3.Bucket(s3_bucket).objects.filter(
                 Prefix=os.path.commonprefix(object_paths)
             )
@@ -35,7 +36,7 @@ def _generate_transfer_mapping(
     else:
         # modes: file -> directory, directory -> directory
         assert destination[-1] == "/", "Must point to a directory in object store."
-        source = pathlib.Path(source).as_posix().resolve()
+        source = pathlib.Path(source).resolve()
         # recursively list files that are not hidden or directories
         file_paths = {
             fp.relative_to(source)
@@ -43,17 +44,19 @@ def _generate_transfer_mapping(
             if not fp.is_dir() and not str(fp.name).startswith(".")
         }
         file_paths = (
-            file_paths if file_paths else {pathlib.Path(source.name).as_posix()}
+            {pathlib.PurePosixPath(_) for _ in file_paths}
+            if file_paths
+            else {pathlib.PurePosixPath(source.name)}
         )  # if specified a single file
         # recursively list objects
         existing_objects = {
-            pathlib.Path(op.key.replace(destination, "")).as_posix()
+            pathlib.PurePosixPath(op.key.replace(destination, ""))
             for op in session.s3.Bucket(s3_bucket).objects.filter(Prefix=destination)
         }
         # exclude objects that exist and verify that new objects are present
         file_paths = file_paths - existing_objects
         assert file_paths, "All files already exist in object store."
-        object_paths = [pathlib.Path(destination, fp).as_posix() for fp in file_paths]
+        object_paths = [pathlib.PurePosixPath(destination, fp) for fp in file_paths]
         file_paths = [
             pathlib.Path(source if source.is_dir() else source.parent, fp)
             for fp in file_paths
